Module opencv

Module opencv 

Experimental module for image and video manipulation.

Interfaces may change in the future.

Structs

Font
Font to draw text on images.
GrayImage
GrayValue
Represents a pixel with only one component.
GrayValueIterator
MaskIter
Rgb
Represents a pixel with a red, green and blue component.
RgbImage
Video
VideoColorFrameIterator
VideoGrayFrameIterator
Window
A window to display an image.

Enums

FontFace

Traits

Image
Trait for images.

Functions

grid
Creates a new image by organizing the given list of images into a grid.