Experimental module for image and video manipulation.
Interfaces may change in the future.
Structs
- Font
- Font to draw text on images.
- Gray
Image - Gray
Value - Represents a pixel with only one component.
- Gray
Value Iterator - Mask
Iter - Rgb
- Represents a pixel with a red, green and blue component.
- RgbImage
- Video
- Video
Color Frame Iterator - Video
Gray Frame Iterator - Window
- A window to display an image.
Enums
Traits
- Image
- Trait for images.
Functions
- grid
- Creates a new image by organizing the given list of images into a grid.